Examples gallery
================

Below is a list of example scripts showing basic usage for most methods in
MEEGkit.

The examples can be browsed directly on `Github <https://github.com/nbara/python-meegkit/tree/master/examples>`_.

